"""widesutra — Python SDK for WideSutra.

Access Buddhist scriptures, Tipitaka, Pali Canon texts, figures, and concepts
from the WideSutra REST API.

Usage::

    from widesutra import WideSutra

    with WideSutra() as client:
        collections = client.list_collections()
        text = client.get_text("dhammapada", 1, 1)
        results = client.search("four noble truths")
"""

from widesutra.client import WideSutra

__version__ = "0.1.1"

__all__ = [
    "WideSutra",
    "__version__",
]
